In network meta-analysis, standard error estimates cannot often be obtained for some contrasts of arms in multi-arm trials. This function calculate the standard error estimate of a contrast measure (e.g., log hazard ratio) estimator from partially obtained summary data in multi-arm trials. Without loss of generality, we consider three arms 0, 1 and 2 in the corresponding trial, and suppose the standard error of the contrast measure comparing the arms 1 vs. 2 is not obtained; however, those comparing the arms 1 vs. 0 and 2 vs. 0 are obtained. We can calculate the standard error estimate comparing the arms 1 vs. 2 from the partially available data.
calcse(se1,se2,n1,n2,n0)The standard error estimate of a contrast measure (e.g., log hazard ratio) estimator for arms 1 vs. 2.
The standard error estimate of a contrast measure (e.g., log hazard ratio) estimator for arms 1 vs. 0.
The standard error estimate of a contrast measure (e.g., log hazard ratio) estimator for arms 2 vs. 0.
The sample size of arm 1.
The sample size of arm 2.
The sample size of arm 0.
Noma, H. and Maruo, K. (2025). Network meta-analysis combining survival and count outcome data: A simple frequentist approach. medRxiv: 10.1101/2025.01.23.25321051.
Woods, B. S., Hawkins, N., Scott, D. A. (2010). Network meta-analysis on the log-hazard scale, combining count and hazard ratio statistics accounting for multi-arm trials: a tutorial. BMC Medical Research Methodology 10, 54.
calcse(0.096,0.092,1521,1534,1524)
Run the code above in your browser using DataLab