Learn R Programming

survNMA (version 1.1-1)

combine2: Merging two dataset for the analysis by "netmeta"

Description

Merging two dataset for the analysis by netmeta package (e.g., an output object by pairwiseHR for dichotomized outcome dataset and the survival outcome dataset). The output object can be straightforwardly applied to the netmeta function.

Usage

combine2(data1, data2)

Value

  • studlab: ID variable of studies.

  • treat1: The treatment of arm 1.

  • treat2: The treatment of arm 2.

  • TE: The effect measure estimate.

  • seTE: Standard error estimate for the effect measure estimator.

Arguments

data1

Dataset 1.

data2

Dataset 2.

References

Noma, H. and Maruo, K. (2025). Network meta-analysis combining survival and count outcome data: A simple frequentist approach. medRxiv: 10.1101/2025.01.23.25321051.

Examples

Run this code
data(woods1)
data(woods2)

woods3 <- pairwiseHR(treat, studlab=study, event=d, n, data=woods2)
combine2(woods1, woods3)

Run the code above in your browser using DataLab